@@ -12,5 +12,5 @@ from quick_ml import training_predictions
 from quick_ml import predictions
 from quick_ml import augments
 from quick_ml import k_fold_training
-from quick_ml.data_preprocessing import remove_imbalance
-__version__ = '1.3.7'
+import quick_ml.data_preprocessing.remove_imbalance
+__version__ = '1.3.8'
