@@ -1,4 +1,3 @@
-
 def rampup_lrfn(epoch):
 
 	"""
@@ -121,9 +120,7 @@ def get_callbacks(lr_scheduler = None, early_stopping = None, reduce_lr_on_plate
 	return callbacks
 		
 
-if __name__ == "__main__":
-	pass
-else:
+if __name__ != "__main__":
 	global LR_MAX
 	global LR_MIN
 	global LR_RAMPUP_EPOCHS
@@ -142,4 +139,4 @@ else:
 	LR_RAMPUP_EPOCHS = 5
 	LR_SUSTAIN_EPOCHS = 0
 	LR_EXP_DECAY = 0.8
-	LR_START = 0.00001
\ No newline at end of file
+	LR_START = 0.00001
